@@ -91,7 +91,7 @@ def create_tfrecords_from_csv(data_dir, csv_path, outputfilename, IMAGE_SIZE = (
 
 	addrs = glob.glob(data_dir + '/*.jpg')
 	addrs.sort()
-	labels = list(df['Image'])
+	labels = list(df['Id'])
 	
 	labels_dict = {}
 	labels_unique = list(set(labels))
@@ -123,7 +123,7 @@ def create_split_tfrecords_from_csv(data_dir, csv, outfile1name, outfile2name, s
 
 	addrs = glob.glob(data_dir + '/*.jpg')
 	addrs.sort()
-	labels = list(df['Image'])
+	labels = list(df['Id'])
 	
 	labels_dict = {}
 	labels_unique = list(set(labels))
